@@ -15,14 +15,14 @@ import (
 func imageSave(images []string, dest, clusterName string) error {
 	// get a docker client
 	ctx := context.Background()
-	docker, err := client.NewEnvClient()
+	docker, err := client.NewClientWithOpts(client.FromEnv, client.WithAPIVersionNegotiation())
 	if err != nil {
-		return fmt.Errorf("ERROR: couldn't create docker client\n%+v", err)
+		return fmt.Errorf("ERROR: couldn't create docker client\n%w", err)
 	}
 
 	imageReader, err := docker.ImageSave(ctx, images)
 	if err != nil {
-		return fmt.Errorf("ERROR: couldn't save images %s\n%+v", images, err)
+		return fmt.Errorf("ERROR: couldn't save images %s\n%w", images, err)
 	}
 	defer imageReader.Close()
 
@@ -35,12 +35,12 @@ func imageSave(images []string, dest, clusterName string) error {
 	}
 	tarFile, err := os.Create(tarFileName)
 	if err != nil {
-		return fmt.Errorf("ERROR: couldn't create tarfile [%s]\n%+v", tarFileName, err)
+		return fmt.Errorf("ERROR: couldn't create tarfile [%s]\n%w", tarFileName, err)
 	}
 	defer tarFile.Close()
 
 	if _, err = io.Copy(tarFile, imageReader); err != nil {
-		return fmt.Errorf("ERROR: couldn't save image stream to tarfile\n%+v", err)
+		return fmt.Errorf("ERROR: couldn't save image stream to tarfile\n%w", err)
 	}
 
 	log.Printf("INFO: saved images %s to [%s]", images, tarFileName)
